# Github repository for homehubRPi PyPI module.

#### Current package in testing available at github

[homehubRPi](https://test.pypi.org/project/homehubRPi/)

###### Project Desription

HomehubRPI package was specifically made for those wanting to implement bespoke Smart Home ecosystems. Currently runs on all Raspberry Pi's and can be extended to any other boards e.g Arduino, ESP8632, PocketBeagle etc. Only a few twitches would need to be done to suit the specific board type and I/O pin configurations. Some modules work without needing any tweaking. For example HTTPCommunications module.

This package works in tandem with [hubAPI](https://github.com/ngonimombeshora?tab=repositories) which hosts the database and front-end API for developers. This API can be hosted online or on a local server. Otherwise if one wishes they can use the one hosted on the public domain on netlify at [Insert netlify url](https://guides.github.com/features/mastering-markdown/), which still offers the same amount of security and privacy to ones own smart home ecosystem.
